==> qtjambi-qml-debuginfo-macos-6.8.0.jar: sources/QtJambiQml/QQmlParserStatus_shell.cpp <==
#include "QQmlParserStatus_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlParserStatus(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlParserStatus")
    QQmlParserStatus *_ptr = reinterpret_cast<QQmlParserStatus *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlParserStatus_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlParserStatus_shell) ); }

jmethodID QQmlParserStatus_oshell::__shell_javaMethod(int pos) const { return QQmlParserStatus_shell::__shell()->javaMethod(typeid(QQmlParserStatus), pos); }

// emitting (writeShellDestructor)
QQmlParserStatus_shell::~QQmlParserStatus_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlParserStatus::~QQmlParserStatus()", this)
    QQmlParserStatus_shell::__shell()->destructed(typeid(QQmlParserStatus));
}

// emitting (writeShellConstructor)
QQmlParserStatus_shell::QQmlParserStatus_shell()
    : QQmlParserStatus()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlParserStatus::QQmlParserStatus_shell()", this)
    QQmlParserStatus_shell::__shell()->constructed(typeid(QQmlParserStatus));
}

void QQmlParserStatus_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlParserStatus_oshell*>(ptr)->QQmlParserStatus_oshell::__shell()->tryDeleteShell(typeid(QQmlParserStatus));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlParserStatus_oshell::classBegin()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlParserStatus::classBegin()", this)
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlParserStatus_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlParserStatus_shell::__shell()->warnForMethod("QQmlParserStatus::classBegin()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QQmlParserStatus::classBegin()");
            } QTJAMBI_TRY_END
        }
    }
}

void QQmlParserStatus_oshell::componentComplete()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlParserStatus::componentComplete()", this)
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlParserStatus_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlParserStatus_shell::__shell()->warnForMethod("QQmlParserStatus::componentComplete()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QQmlParserStatus::componentComplete()");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlParserStatus_access::__qt_classBegin(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlParserStatus::classBegin()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlParserStatus::classBegin().";
    } else {
        classBegin();
    }
}

void QQmlParserStatus_access::__qt_componentComplete(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlParserStatus::componentComplete()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlParserStatus::componentComplete().";
    } else {
        componentComplete();
    }
}

// emitting (writeConstructors)
// new QQmlParserStatus()
void __qt_construct_QQmlParserStatus(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlParserStatus()")
    Q_UNUSED(__java_arguments)
    QQmlParserStatus *__qt_this = new(__qtjambi_ptr) QQmlParserStatus_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlParserStatus::QQmlParserStatus()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlParserStatus_00024Impl_initialize_1native__Lio_qt_qml_QQmlParserStatus_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlParserStatus::QQmlParserStatus()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlParserStatus, sizeof(QQmlParserStatus_shell), typeid(QQmlParserStatus), 0, true, &deleter_QQmlParserStatus, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlParserStatus_shell
void __qt_destruct_QQmlParserStatus(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlParserStatus")
    reinterpret_cast<QQmlParserStatus_shell*>(ptr)->~QQmlParserStatus_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlParserStatus::classBegin()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlParserStatus_00024Impl_00024ConcreteWrapper_classBegin_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QQmlParserStatus *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlParserStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlParserStatus::classBegin()", __this_nativeId)
        static_cast<QQmlParserStatus_access*>(__qt_this)->__qt_classBegin(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlParserStatus::componentComplete()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlParserStatus_00024Impl_00024ConcreteWrapper_componentComplete_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QQmlParserStatus *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlParserStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlParserStatus::componentComplete()", __this_nativeId)
        static_cast<QQmlParserStatus_access*>(__qt_this)->__qt_componentComplete(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlParserStatus(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlParserStatus>("QQmlParserStatus", "io/qt/qml/QQmlParserStatus");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "classBegin", "()V", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "componentComplete", "()V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlParserStatus, {
        ConstructorInfo(&__qt_construct_QQmlParserStatus, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlParserStatus);
    registerSizeOfShell(typeId, sizeof(QQmlParserStatus_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlParserStatus* _object = dynamic_cast<QQmlParserStatus*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlParserStatus *object = reinterpret_cast<QQmlParserStatus *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlParserStatus *object = reinterpret_cast<const QQmlParserStatus *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.9.1.jar: sources/QtJambiQml/QQmlParserStatus_shell.cpp <==
#include "QQmlParserStatus_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlParserStatus(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlParserStatus")
    QQmlParserStatus *_ptr = reinterpret_cast<QQmlParserStatus *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlParserStatus_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlParserStatus_shell) ); }

jmethodID QQmlParserStatus_oshell::__shell_javaMethod(int pos) const { return QQmlParserStatus_shell::__shell()->javaMethod(typeid(QQmlParserStatus), pos); }

// emitting (writeShellDestructor)
QQmlParserStatus_shell::~QQmlParserStatus_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlParserStatus::~QQmlParserStatus()", this)
    QQmlParserStatus_shell::__shell()->destructed(typeid(QQmlParserStatus));
}

// emitting (writeShellConstructor)
QQmlParserStatus_shell::QQmlParserStatus_shell()
    : QQmlParserStatus()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlParserStatus::QQmlParserStatus_shell()", this)
    QQmlParserStatus_shell::__shell()->constructed(typeid(QQmlParserStatus));
}

void QQmlParserStatus_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlParserStatus_oshell*>(ptr)->QQmlParserStatus_oshell::__shell()->tryDeleteShell(typeid(QQmlParserStatus));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlParserStatus_oshell::classBegin()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlParserStatus::classBegin()", this)
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlParserStatus_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlParserStatus_shell::__shell()->warnForMethod("QQmlParserStatus::classBegin()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, this, "QQmlParserStatus::classBegin()");
            } QTJAMBI_TRY_END
        }
    }
}

void QQmlParserStatus_oshell::componentComplete()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlParserStatus::componentComplete()", this)
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlParserStatus_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlParserStatus_shell::__shell()->warnForMethod("QQmlParserStatus::componentComplete()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, this, "QQmlParserStatus::componentComplete()");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlParserStatus_access::__qt_classBegin(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlParserStatus::classBegin()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlParserStatus::classBegin().";
    } else {
        classBegin();
    }
}

void QQmlParserStatus_access::__qt_componentComplete(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlParserStatus::componentComplete()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlParserStatus::componentComplete().";
    } else {
        componentComplete();
    }
}

// emitting (writeConstructors)
// new QQmlParserStatus()
void __qt_construct_QQmlParserStatus(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlParserStatus()")
    Q_UNUSED(__java_arguments)
    QQmlParserStatus *__qt_this = new(__qtjambi_ptr) QQmlParserStatus_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlParserStatus::QQmlParserStatus()
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlParserStatus_00024Impl_initialize_1native__Lio_qt_qml_QQmlParserStatus_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlParserStatus::QQmlParserStatus()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlParserStatus, sizeof(QQmlParserStatus_shell), typeid(QQmlParserStatus), 0, true, &deleter_QQmlParserStatus, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlParserStatus_shell
void __qt_destruct_QQmlParserStatus(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlParserStatus")
    reinterpret_cast<QQmlParserStatus_shell*>(ptr)->~QQmlParserStatus_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlParserStatus::classBegin()
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlParserStatus_00024Impl_00024ConcreteWrapper_classBegin_1native__J
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QQmlParserStatus *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlParserStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlParserStatus::classBegin()", __this_nativeId)
        static_cast<QQmlParserStatus_access*>(__qt_this)->__qt_classBegin(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlParserStatus::componentComplete()
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlParserStatus_00024Impl_00024ConcreteWrapper_componentComplete_1native__J
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QQmlParserStatus *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlParserStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlParserStatus::componentComplete()", __this_nativeId)
        static_cast<QQmlParserStatus_access*>(__qt_this)->__qt_componentComplete(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlParserStatus(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlParserStatus>("QQmlParserStatus", "io/qt/qml/QQmlParserStatus");
    registerFunctionInfos(typeId, {
        FunctionInfo{/* 0 */ "classBegin", "()V", FunctionInfo::Abstract},
        FunctionInfo{/* 1 */ "componentComplete", "()V", FunctionInfo::Abstract}});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlParserStatus, {
        ConstructorInfo{&__qt_construct_QQmlParserStatus, nullptr}
    });
    registerDeleter(typeId, &deleter_QQmlParserStatus);
    registerSizeOfShell(typeId, sizeof(QQmlParserStatus_shell));
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlParserStatus* _object = dynamic_cast<QQmlParserStatus*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlParserStatus *object = reinterpret_cast<QQmlParserStatus *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlParserStatus *object = reinterpret_cast<const QQmlParserStatus *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
}
